#!/usr/bin/env node
"use strict";
var __awaiter =
  (this && this.__awaiter) ||
  function (thisArg, _arguments, P, generator) {
    function adopt(value) {
      return value instanceof P
        ? value
        : new P(function (resolve) {
            resolve(value);
          });
    }
    return new (P || (P = Promise))(function (resolve, reject) {
      function fulfilled(value) {
        try {
          step(generator.next(value));
        } catch (e) {
          reject(e);
        }
      }
      function rejected(value) {
        try {
          step(generator["throw"](value));
        } catch (e) {
          reject(e);
        }
      }
      function step(result) {
        result.done
          ? resolve(result.value)
          : adopt(result.value).then(fulfilled, rejected);
      }
      step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
  };
var __importDefault =
  (this && this.__importDefault) ||
  function (mod) {
    return mod && mod.__esModule ? mod : { default: mod };
  };
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const minimist_1 = __importDefault(require("minimist"));
const ora_1 = __importDefault(require("ora"));
const chalk_1 = __importDefault(require("chalk"));
const openHTMLInBrowser_1 = __importDefault(
  require("./utils/openHTMLInBrowser")
);
const getAllFiles_1 = __importDefault(require("./utils/getAllFiles"));
const mapFileNameToExtention_1 = __importDefault(
  require("./utils/mapFileNameToExtention")
);
const createOutputDir_1 = __importDefault(require("./utils/createOutputDir"));
const getChildren_1 = __importDefault(require("./utils/getChildren"));
if (process.env.NODE_ENV !== "test" && process.env.NODE_ENV !== "dev") {
  process.env.NODE_ENV = "production";
}
function init(root) {
  return __awaiter(this, void 0, void 0, function* () {
    if (typeof root !== "string") {
      console.log(chalk_1.default.red.bold("Error: Invalid entry file!"));
      console.log(
        chalk_1.default.red.yellow.bold(
          "--entryFile file should be like this: --entryFile=src/index.js"
        )
      );
      process.exit(1);
    }
    const baseDir = process.cwd();
    const rootFile = path_1.default.join(baseDir, root);
    const spinner = ora_1.default("Reading files...").start();
    const files = yield getAllFiles_1.default(baseDir);
    spinner.succeed();
    spinner.text = "Extracting extensions...";
    spinner.start();
    const map = mapFileNameToExtention_1.default(files);
    spinner.succeed();
    spinner.text = "Building component tree...";
    spinner.start();
    const outputJSON = yield getChildren_1.default(rootFile, map);
    const outputStr = JSON.stringify(outputJSON, null, 2);
    spinner.succeed();
    spinner.text = "Generating output files...";
    spinner.start();
    const outputDirPath = createOutputDir_1.default(baseDir, outputStr);
    spinner.succeed();
    if (process.env.NODE_ENV === "production") {
      openHTMLInBrowser_1.default(
        path_1.default.join(outputDirPath, "index.html")
      );
    }
    console.log(
      chalk_1.default.green.bold(
        `Visualization is ready: ${chalk_1.default.underline(
          path_1.default.join(outputDirPath, "/index.html")
        )}`
      )
    );
  });
}
if (process.env.NODE_ENV === "production") {
  const args = minimist_1.default(process.argv.slice(2));
  if (!args["entryFile"]) {
    console.error(
      chalk_1.default.red.bold("Error: --entryFile flag is required.")
    );
    process.exit(1);
  }
  init(args["entryFile"]);
} else {
  init("./src/index.ts");
}
