"use strict";
var __awaiter =
  (this && this.__awaiter) ||
  function (thisArg, _arguments, P, generator) {
    function adopt(value) {
      return value instanceof P
        ? value
        : new P(function (resolve) {
            resolve(value);
          });
    }
    return new (P || (P = Promise))(function (resolve, reject) {
      function fulfilled(value) {
        try {
          step(generator.next(value));
        } catch (e) {
          reject(e);
        }
      }
      function rejected(value) {
        try {
          step(generator["throw"](value));
        } catch (e) {
          reject(e);
        }
      }
      function step(result) {
        result.done
          ? resolve(result.value)
          : adopt(result.value).then(fulfilled, rejected);
      }
      step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
  };
var __importDefault =
  (this && this.__importDefault) ||
  function (mod) {
    return mod && mod.__esModule ? mod : { default: mod };
  };
Object.defineProperty(exports, "__esModule", { value: true });
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const getFilePathFromMatch_1 = __importDefault(
  require("./getFilePathFromMatch")
);
const isDir_1 = __importDefault(require("./isDir"));
const getExtension_1 = __importDefault(require("./getExtension"));
const chalk_1 = __importDefault(require("chalk"));
let currentStack = [];
function getChildren(rootFile, map) {
  return __awaiter(this, void 0, void 0, function* () {
    let content;
    try {
      content = yield fs_extra_1.default.readFile(rootFile, {
        encoding: "utf8",
      });
    } catch (err) {
      console.log(
        chalk_1.default.red.bold("\nError: Could not found the file", rootFile)
      );
      console.log(
        chalk_1.default.red.yellow.bold(
          "Make sure the file has the correct extension."
        )
      );
      process.exit(1);
    }
    if (!currentStack.includes(rootFile)) {
      currentStack.push(rootFile);
      let matches = content.match(
        /import\s+[\w-]+\s+from(\s|\R)*("|')\s*\.{1,2}\/.+("|')/gim
      );
      let children = [];
      if (matches) {
        for (let index = 0; index < matches.length; index++) {
          const match = matches[index];
          const dirName = path_1.default.dirname(rootFile);
          let normalized = path_1.default.resolve(
            dirName,
            getFilePathFromMatch_1.default(match)
          );
          const isDirFlag = isDir_1.default(normalized);
          let baseName = path_1.default.basename(normalized);
          let lastDotIndex = baseName.lastIndexOf(".");
          let extension;
          try {
            if (lastDotIndex > 0) {
              extension = "";
            } else {
              extension = getExtension_1.default(normalized, baseName, map);
            }
          } catch (err) {
            if (isDirFlag) {
              baseName = "index";
              normalized = path_1.default.join(normalized, baseName);
              extension = getExtension_1.default(normalized, baseName, map);
            } else {
              console.log(
                chalk_1.default.red.bold(
                  "\nError: Could not found the file",
                  normalized
                )
              );
              process.exit(1);
            }
          }
          const pathName = normalized + extension;
          children.push(yield getChildren(pathName, map));
        }
      }
      currentStack = currentStack.slice(0, currentStack.length - 1);
      return {
        path: path_1.default.basename(rootFile),
        children: children.length < 1 ? null : children,
      };
    } else {
      return {
        path: path_1.default.basename(rootFile),
        children: null,
      };
    }
  });
}
exports.default = getChildren;
